@@ -1,7 +1,7 @@
 """
 The MIT License (MIT)
 
-Copyright (c) 2020 AbstractUmbra
+Copyright (c) 2020-Present AbstractUmbra
 
 Permission is hereby granted, free of charge, to any person obtaining a
 copy of this software and associated documentation files (the "Software"),
@@ -22,11 +22,22 @@ FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 DEALINGS IN THE SOFTWARE.
 """
 
-from collections import namedtuple
+from typing import Literal, NamedTuple
 
-from .client import HTTPClient as Client
+from .client import Client as Client
+from .client import SyncClient as SyncClient
 from .errors import *
+from .objects import Paste as Paste
+from .objects import PasteData as PasteData
 
-__version__ = "1.0.1"
-VersionInfo = namedtuple("VersionInfo", "major minor micro releaselevel serial")
-version_info = VersionInfo(major=2, minor=1, micro=3, releaselevel="final", serial=0)
+
+class VersionInfo(NamedTuple):
+    major: int
+    minor: int
+    micro: int
+    releaselevel: Literal["alpha", "beta", "candidate", "final"]
+    serial: int
+
+
+__version__ = "4.0.0"
+version_info: VersionInfo = VersionInfo(major=4, minor=0, micro=0, releaselevel="final", serial=0)
